@@ -2294,28 +2294,6 @@ libGAP_Obj libGAP_GcdInt ( libGAP_Obj opL, libGAP_Obj opR )
   return gcd;
 }
 
-libGAP_Obj libGAP_FuncIntDiv2( libGAP_Obj self, libGAP_Obj gmp )
-{
-  libGAP_Obj res;
-  libGAP_Int p,r;
-  libGAP_TypLimb bmask;
-
-    p=r=0;
-    /*    gmp = NEW_INT(arg);*/
-
-    /* find highest power of 2 dividing gmp and divide out by this */
-    for ( p = 0 ; libGAP_ADDR_INT(gmp)[p] == (libGAP_TypLimb)0; p++ ) {
-      ;
-    }
-    for ( bmask = (libGAP_TypLimb)1, r = 0 ;
-          ( (bmask & libGAP_ADDR_INT(gmp)[p]) == 0 ) && bmask != (libGAP_TypLimb)0 ;
-          bmask = bmask << 1, r++ ) {
-      ;
-    }
-    res = libGAP_INTOBJ_INT( p*1000 + r );
-    return res;
-}
-
 /****************************************************************************
 **
 *F  FuncGCD_INT(<self>,<opL>,<opR>)  . . . . . . .  internal function 'GcdInt'
@@ -2522,9 +2500,6 @@ static libGAP_StructGVarFunc libGAP_GVarFuncs [] = {
   { "Log2Int", 1, "gmp",
     libGAP_FuncLog2Int, "src/gmpints.c:Log2Int" },
 
-  { "IntDiv2", 1, "gmp",
-    libGAP_FuncIntDiv2, "src/gmpints.c:IntDiv2" },
-
   { "STRING_INT", 1, "gmp",
     libGAP_FuncSTRING_INT, "src/gmpints.c:STRING_INT" },
   
